get_border: Identify all border points in a region

View source: R/get_border.R

get_borderR Documentation

Identify all border points in a region

Description

Identify all border points in a region

Usage

get_border(region, e)

Arguments

region

A data frame containing the x and y coordinates of the region.

e

The step size of the grid in the x and y directions.

Value

A data frame containing the x and y coordinates of the border points of the region.


bate documentation built on March 28, 2022, 9:11 a.m.