mycubic: Compute roots of the cubic equation

View source: R/mycubic.R

mycubicR Documentation

Compute roots of the cubic equation

Description

Compute roots of the cubic equation

Usage

mycubic(parameters, mydelta, Rmax)

Arguments

parameters

A vector of parameters (real numbers) that is generated by estimating the short, intermediate and auxiliary regressions.

mydelta

Value of delta (real number).

Rmax

Value of Rmax (real number).

Value

A vector containing the three roots of the cubic equation defined by the parameters, delta and Rmax.


bate documentation built on March 28, 2022, 9:11 a.m.